@@ -5,16 +5,13 @@
 #include "abstractaccount.h"
 
 #include "accountmanager.h"
-#include "network/networkcontroller.h"
-#include "preferences.h"
+#include "messagefiltercontainer.h"
+#include "navigation.h"
+#include "networkcontroller.h"
 #include "relationship.h"
 #include "tokodon_debug.h"
-#include "utils/messagefiltercontainer.h"
+
 #include <KLocalizedString>
-#include <QFile>
-#include <QHttpMultiPart>
-#include <QNetworkReply>
-#include <QUrlQuery>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -125,19 +122,24 @@ void AbstractAccount::registerApplication(const QString &appName, const QString
     // clear any previous bearer token credentials
     m_token = QString();
 
+    QString ourAdditionalScopes;
+#ifdef HAVE_KUNIFIEDPUSH
+    ourAdditionalScopes = QStringLiteral("push ");
+#endif
+
+    // Store for future usage (e.g. authorizeUrl)
+    m_additionalScopes = ourAdditionalScopes + additionalScopes;
+
     // register
     const QUrl regUrl = apiUrl(QStringLiteral("/api/v1/apps"));
     const QJsonObject obj{
         {QStringLiteral("client_name"), appName},
         {QStringLiteral("redirect_uris"), QStringLiteral("tokodon://oauth")},
-        {QStringLiteral("scopes"), QStringLiteral("read write follow push %1").arg(additionalScopes)},
+        {QStringLiteral("scopes"), QStringLiteral("read write follow %1").arg(m_additionalScopes)},
         {QStringLiteral("website"), website},
     };
     const QJsonDocument doc(obj);
 
-    // Store for future usage (e.g. authorizeUrl)
-    m_additionalScopes = additionalScopes;
-
     post(regUrl, doc, false, this, [=](QNetworkReply *reply) {
         if (!reply->isFinished()) {
             qCDebug(TOKODON_LOG) << "not finished";
@@ -252,6 +254,35 @@ std::shared_ptr<AdminAccountInfo> AbstractAccount::adminIdentityLookup(const QSt
     return m_adminIdentityCache[accountId];
 }
 
+AdminAccountInfo *AbstractAccount::adminIdentityLookupWithVanillaPointer(const QString &accountId, const QJsonObject &doc)
+{
+    const auto id = new AdminAccountInfo();
+
+    id->reparentAdminAccountInfo(this);
+    id->fromSourceData(doc);
+    m_adminIdentityCacheWithVanillaPointer[accountId] = id;
+
+    return m_adminIdentityCacheWithVanillaPointer[accountId];
+}
+
+std::shared_ptr<ReportInfo> AbstractAccount::reportInfoLookup(const QString &reportId, const QJsonObject &doc)
+{
+    if (m_reportInfo && m_reportInfo->reportId() == reportId) {
+        return m_reportInfo;
+    }
+    auto id = m_reportInfoCache[reportId];
+    if (id && id->reportId() == reportId) {
+        return id;
+    }
+
+    id = std::make_shared<ReportInfo>();
+    id->reparentReportInfo(this);
+    id->fromSourceData(doc);
+    m_reportInfoCache[reportId] = id;
+
+    return m_reportInfoCache[reportId];
+}
+
 bool AbstractAccount::identityCached(const QString &accountId) const
 {
     if (m_identity && m_identity->id() == accountId) {
@@ -273,7 +304,7 @@ QUrl AbstractAccount::getAuthorizeUrl() const
 
     q.addQueryItem(QStringLiteral("redirect_uri"), QStringLiteral("tokodon://oauth"));
     q.addQueryItem(QStringLiteral("response_type"), QStringLiteral("code"));
-    q.addQueryItem(QStringLiteral("scope"), QStringLiteral("read write follow push ") + m_additionalScopes);
+    q.addQueryItem(QStringLiteral("scope"), QStringLiteral("read write follow ") + m_additionalScopes);
 
     url.setQuery(q);
 
@@ -286,8 +317,7 @@ void AbstractAccount::setAccessToken(const QString &token)
     s_messageFilter->insert(m_token, QStringLiteral("ACCESS_TOKEN"));
     AccountManager::instance().addAccount(this, false);
     AccountManager::instance().selectAccount(this, true);
-    validateToken();
-    writeToSettings();
+    validateToken(true);
 }
 
 QUrl AbstractAccount::getTokenUrl() const
@@ -711,8 +741,31 @@ void AbstractAccount::mutateRemotePost(const QString &url, const QString &verb)
         if (!statuses.isEmpty()) {
             const auto status = statuses[0].toObject();
 
-            const QString localID = status["id"_L1].toString();
-            mutatePost(localID, verb);
+            if (verb == QStringLiteral("reply")) {
+                // TODO: we can't delete this immediately, will need some smarter cleanup in the PostEditorBackend
+                Post *post = new Post(this, this);
+                post->fromJson(status);
+                Q_EMIT Navigation::instance().replyTo(post->postId(), post->mentions(), post->visibility(), post->getAuthorIdentity(), post);
+            } else {
+                const QString localID = status["id"_L1].toString();
+                mutatePost(localID, verb);
+            }
+        }
+    });
+}
+
+void AbstractAccount::fetchOEmbed(const QString &id, Identity *identity)
+{
+    QUrlQuery query;
+    query.addQueryItem(QStringLiteral("url"), QStringLiteral("%1/@%2/%3").arg(m_instance_uri, identity->username(), id));
+
+    QUrl oembedUrl = apiUrl(QStringLiteral("/api/oembed"));
+    oembedUrl.setQuery(query);
+
+    get(oembedUrl, false, this, [this](QNetworkReply *reply) {
+        const auto doc = QJsonDocument::fromJson(reply->readAll());
+        if (doc.object().contains("html"_L1)) {
+            Q_EMIT fetchedOEmbed(doc.object()["html"_L1].toString());
         }
     });
 }
@@ -783,3 +836,5 @@ QList<CustomEmoji> AbstractAccount::customEmojis() const
 {
     return m_customEmojis;
 }
+
+#include "moc_abstractaccount.cpp"
\ No newline at end of file
