@@ -4,16 +4,14 @@
 #pragma once
 
 #include "accountconfig.h"
-#include "admin/adminaccountinfo.h"
-#include "admin/federationinfo.h"
+#include "adminaccountinfo.h"
+#include "customemoji.h"
 #include "identity.h"
 #include "preferences.h"
-#include "timeline/post.h"
-#include "utils/customemoji.h"
+#include "reportinfo.h"
 
 #include <QJsonDocument>
 #include <QJsonObject>
-#include <QObject>
 
 class Attachment;
 class Notification;
@@ -98,7 +96,7 @@ public:
     bool hasInstanceUrl() const;
 
     /// Verifies the token with the instance and if successful, loads identity information for the account
-    Q_INVOKABLE virtual void validateToken() = 0;
+    Q_INVOKABLE virtual void validateToken(bool newAccount = false) = 0;
 
     /// Return local account preferences
     AccountConfig *config();
@@ -165,6 +163,12 @@ public:
     /// \param doc doc Optionally provide an existing account JSON, if you were already given some in another request
     std::shared_ptr<AdminAccountInfo> adminIdentityLookup(const QString &accountId, const QJsonObject &doc);
 
+    /// Vanilla pointer identity
+    AdminAccountInfo *adminIdentityLookupWithVanillaPointer(const QString &accountId, const QJsonObject &doc);
+
+    /// Populating with Admin::Report
+    std::shared_ptr<ReportInfo> reportInfoLookup(const QString &reportId, const QJsonObject &doc);
+
     /// Invalidates the account
     void invalidate();
 
@@ -372,6 +376,10 @@ public:
 
     Q_INVOKABLE void mutateRemotePost(const QString &url, const QString &verb);
 
+    /// Fetches OEmbed data for a post.
+    /// @param QString url the url of the post to fetch.
+    Q_INVOKABLE void fetchOEmbed(const QString &id, Identity *identity);
+
     /// Returns the preferred settings group name for this Account which includes the username and the instance uri.
     QString settingsGroupName() const;
 
@@ -468,6 +476,10 @@ Q_SIGNALS:
     /// \param json The JSON body for further processing
     void registrationError(const QString &json);
 
+    /// Emitted when the oembed data is successfully returned.
+    /// \see fetchOEmbed
+    void fetchedOEmbed(const QString &html);
+
 protected:
     QString m_name;
     QString m_instance_uri;
@@ -479,9 +491,12 @@ protected:
     bool m_supportsLocalVisibility;
     size_t m_charactersReservedPerUrl;
     QString m_instance_name;
+    QJsonArray m_instance_rules;
     std::shared_ptr<Identity> m_identity;
     std::shared_ptr<AdminAccountInfo> m_adminIdentity;
+    AdminAccountInfo *m_adminIdentityWithVanillaPointer;
     AdminAccountInfo *m_federationIdentity;
+    std::shared_ptr<ReportInfo> m_reportInfo;
     AllowedContentType m_allowedContentTypes;
     Preferences *m_preferences = nullptr;
     QList<CustomEmoji> m_customEmojis;
@@ -501,6 +516,8 @@ protected:
     void mutatePost(const QString &id, const QString &verb, bool deliver_home = false);
     QMap<QString, std::shared_ptr<Identity>> m_identityCache;
     QMap<QString, std::shared_ptr<AdminAccountInfo>> m_adminIdentityCache;
+    QMap<QString, AdminAccountInfo *> m_adminIdentityCacheWithVanillaPointer;
+    QMap<QString, std::shared_ptr<ReportInfo>> m_reportInfoCache;
 
     void executeAction(Identity *i, AccountAction accountAction, const QJsonObject &extraArguments = {});
 };
