@@ -17,6 +17,7 @@ AccountManager::AccountManager(QObject *parent)
     : QAbstractListModel(parent)
     , m_selected_account(nullptr)
     , m_qnam(NetworkAccessManagerFactory().create(this))
+    , m_notificationHandler(new NotificationHandler(m_qnam, this))
 {
 }
 
@@ -94,6 +95,11 @@ bool AccountManager::hasAnyAccounts() const
     return m_hasAnyAccounts;
 }
 
+NotificationHandler *AccountManager::notificationHandler() const
+{
+    return m_notificationHandler;
+}
+
 void AccountManager::addAccount(AbstractAccount *account, bool skipAuthenticationCheck)
 {
     beginInsertRows(QModelIndex(), m_accounts.size(), m_accounts.size());
@@ -141,6 +147,7 @@ void AccountManager::addAccount(AbstractAccount *account, bool skipAuthenticatio
         Q_EMIT invalidatedPost(account, p);
     });
     connect(account, &Account::notification, this, [this, account](std::shared_ptr<Notification> n) {
+        AccountManager::instance().notificationHandler()->handle(std::move(n), account);
         Q_EMIT notification(account, std::move(n));
     });
 
@@ -497,11 +504,12 @@ bool AccountManager::testMode() const
 
 void AccountManager::queueNotifications()
 {
-    static int accountsLeft = m_accounts.size();
+    static qsizetype accountsLeft = m_accounts.size();
+    static qsizetype totalNotifications = 0;
 
     const auto checkIfDone = [this]() {
-        qInfo() << "Accounts left to check:" << accountsLeft;
-        if (accountsLeft <= 0) {
+        // If there's no more accounts left to check, and none of them have notifications then early exit
+        if (accountsLeft <= 0 && totalNotifications <= 0) {
             Q_EMIT finishedNotificationQueue();
         }
     };
@@ -516,7 +524,7 @@ void AccountManager::queueNotifications()
         QUrlQuery urlQuery(uri);
         urlQuery.addQueryItem(QStringLiteral("limit"), QString::number(10));
         if (!config.lastPushNotification().isEmpty()) {
-            urlQuery.addQueryItem(QStringLiteral("min_id"), config.lastPushNotification());
+            urlQuery.addQueryItem(QStringLiteral("since_id"), config.lastPushNotification());
         }
         uri.setQuery(urlQuery);
 
@@ -534,9 +542,14 @@ void AccountManager::queueNotifications()
                     return;
                 }
 
-                for (auto notification : doc.array()) {
-                    if (notification.isObject()) {
-                        std::shared_ptr<Notification> n = std::make_shared<Notification>(account, notification.toObject());
+                // We want to post the notifications in reverse order, because the way Plasma displays them.
+                // If we post the newest notification, it would be buried by the older ones.
+                auto notifications = doc.array().toVariantList();
+                std::reverse(notifications.begin(), notifications.end());
+
+                for (const auto &notification : notifications) {
+                    if (notification.canConvert<QJsonObject>()) {
+                        std::shared_ptr<Notification> n = std::make_shared<Notification>(account, notification.toJsonObject());
                         Q_EMIT account->notification(n);
                     }
                 }
@@ -545,6 +558,8 @@ void AccountManager::queueNotifications()
                 config.setLastPushNotification(doc.array().first()["id"_L1].toString());
                 config.save();
 
+                totalNotifications = doc.array().size();
+
                 accountsLeft--;
                 checkIfDone();
             },
