@@ -3,16 +3,11 @@
 
 #include "socialgraphmodel.h"
 
-#include "identity.h"
-
 #include "abstractaccount.h"
 #include "accountmanager.h"
 #include "relationship.h"
+
 #include <KLocalizedString>
-#include <QFile>
-#include <QJsonDocument>
-#include <QNetworkReply>
-#include <qstringliteral.h>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -316,3 +311,5 @@ void SocialGraphModel::fillTimeline()
         setLoading(false);
     });
 }
+
+#include "moc_socialgraphmodel.cpp"
\ No newline at end of file
