@@ -3,9 +3,6 @@
 
 #include "poll.h"
 
-#include <QJsonArray>
-#include <algorithm>
-
 #include "utils/customemoji.h"
 
 using namespace Qt::Literals::StringLiterals;
@@ -86,3 +83,5 @@ QList<QVariantMap> Poll::options() const
 {
     return m_options;
 }
+
+#include "moc_poll.cpp"
